#
# spec file for package python3-apache-libcloud
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-apache-libcloud
Version:        0.17.0
Release:        8.2
Summary:        Abstract away differences among multiple cloud provider APIs
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://libcloud.apache.org
Source0:        http://pypi.python.org/packages/source/a/apache-libcloud/apache-libcloud-%{version}.tar.bz2
Patch0:         python3-apache-libcloud-ssl_match_hostname.patch
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  python3-xml
%endif
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-simplejson
%if %{defined fedora}
Provides:       python3-libcloud
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Apache Libcloud is a standard Python library that abstracts away 
differences among multiple cloud provider APIs.

%prep
%setup -q -n apache-libcloud-%{version}
%patch0 -p1

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%if 0%{?suse_version}
%fdupes %{buildroot}%{python3_sitelib}/libcloud/test/
%endif

%files
%defattr(-,root,root)
%doc LICENSE CHANGES.rst README.rst
%{python3_sitelib}/*

%changelog
* Fri Jun 19 2015 termim@gmail.com
- Fix rpm group name in the spec file
* Sat Feb 28 2015 andrea@opensuse.org
- added python3-apache-libcloud-ssl_match_hostname.patch
- removed python3-backports.ssl_match_hostname from dependency list,
  with the patch now in place, we use native funztions instead of
  an external additional package
* Sat Feb 28 2015 andrea@opensuse.org
- added python3-backports.ssl_match_hostname as dependency
* Fri Feb 20 2015 arun@gmx.de
- specfile:
  * update copyright year
  * added README.rst and CHANGES.rst to %%doc section
- update to version 0.17.0:
  * General
  - Use match_hostname function from backports.ssl_match_hostname
    package to verify the SSL certificate hostname instead of
    relying on our own logic. (GITHUB-374) [Alex Gaynor]
  * Compute
  - GCE driver updated to include ex_stop_node() and ex_start_node()
    methods. (GITHUB-442) [Eric Johnson]
  - GCE driver now raises ResourceNotFoundError when the specified
    image is not found in any image project. Previously, this would
    return None but now raises the not-found exception instead. This
    fixes a bug where returning None caused ex_delete_image to raise
    an AttributeError. (GITHUB-441) [Eric Johnson]
  - GCE driver update to support JSON format Service Account files
    and a PY3 fix from Siim Põder for LIBCLOUD-627. (LIBCLOUD-627,
    LIBCLOUD-657, GITHUB-438) [Eric Johnson]
  - GCE driver fixed for missing param on
    ex_add_access_config. (GITHUB-435) [Peter Mooshammer]
  - GCE driver support for HTTP load-balancer
    resources. (LIBCLOUD-605, GITHUB-429) [Lee Verberne]
  - GCE driver updated to make better use of
    GCEDiskTypes. (GITHUB-428) [Eric Johnson]
  - GCE driver list_images() now returns all non-deprecated images
    by default. (LIBCLOUD-602, GITHUB-423) [Eric Johnson]
  - Improve GCE API coverage for create_node(). (GITHUB-419) [Eric
    Johnson]
  - GCE Licenses added to the GCE driver. (GITHUB-420) [Eric
    Johnson]
  - GCE Projects support common instance metadata and usage export
    buckets. (GITHUB-409) [Eric Johnson]
  - Improvements to TargetPool resource in GCE driver. (GITHUB-414)
    [Eric Johnson]
  - Adding TargetInstances resource to GCE driver. (GITHUB-393)
    [Eric Johnson]
  - Adding DiskTypes resource to GCE driver. (GITHUB-391) [Eric
    Johnson]
  - Fix boot disk auto_delete in GCE driver. (GITHUB-412) [Igor
    Bogomazov]
  - Add Routes to GCE driver. (GITHUB-410) [Eric Johnson]
  - Add missing ubuntu-os-cloud images to the GCE
    driver. (LIBCLOUD-632, GITHUB-385) [Borja Martin]
  - Add new us-east-2 and us-east-3 region to the Joyent
    driver. (GITHUB-386) [ZuluPro]
  - Add missing t2. instance types to the us-west-1 region in the
    EC2 driver. (GITHUB-388) [Matt Lehman]
  - Add option to expunge VM on destroy in CloudStack
    driver. (GITHUB-382) [Roeland Kuipers]
  - Add extra attribute in list_images for CloudStack
    driver. (GITHUB-389) [Loic Lambiel]
  - Add ex_security_group_ids argument to the create_node method in
    the EC2 driver. This way users can launch VPC nodes with
    security groups. (GITHUB-373) [Itxaka Serrano]
  - Add description argument to GCE Network. (GITHUB-397) [Eric
    Johnson]
  - GCE: Improve MachineType (size) coverage of GCE
    API. (GITHUB-396) [Eric Johnson]
  - GCE: Improved Images coverage. (GITHUB-395) [Eric Johnson]
  - GCE: Support for global IP addresses. (GITHUB-390, GITHUB-394)
    [Eric Johnson]
  - GCE: Add missing snapshot attributes. (GITHUB-401) [Eric
    Johnson]
  - AWS: Set proper disk size in c3.X instance types. (GITHUB-405)
    [Itxaka Serrano]
  - Fix a bug with handling of the ex_keyname argument in the
    Softlayer driver. (GITHUB-416, LIBCLOUD-647) [Dustin Oberloh]
  - Update CloudSigma region list (remove Las Vegas, NV region and
    add new San Jose, CA and Miami, FL region). (GITHUB-417) [Viktor
    Petersson]
  - Add ex_get_node method to the Joyent driver. (GITHUB-421)
    [ZuluPro]
  - Add support for placement group management to the EC2
    driver. (GITHUB-418) [Mikhail Ovsyannikov]
  - Add new tok02 region to the Softlayer driver. (GITHUB-436,
    LIBCLOUD-656) [Dustin Oberloh]
  - Add new Honolulu, HI endpoint to the CloudSigma
    driver. (GITHUB-439) [Stephen D. Spencer]
  - Fix a bug with config_drive attribute in the OpenStack
    driver. New versions of OpenStack now return a boolean and not a
    string. (GITHUB-433) [quilombo]
  - Add support for Abiquo API v3.x, remove support for now obsolete
    API v2.x. (GITHUB-433, LIBCLOUD-652) [David Freedman]
  - Allow rootdisksize parameter in create_node CloudStack driver
    (GITHUB-440, LIBCLOUD-658) [Loic Lambiel]
  * Storage
  - Allow user to pass headers argument to the upload_object and
    upload_object_via_stream method.
  - This way user can specify CORS headers with the drivers which
    support that. (GITHUB-403, GITHUB-404) [Peter Schmidt]
  - Fix upload_object_via_stream so it works correctly under Python
    3.x if user manually passes an iterator to the method.
  - Also improve how reading a file in chunks works with drivers
    which support chunked encoding - always try to fill a chunk with
    CHUNK_SIZE bytes instead of directly streaming the chunk which
    iterator returns.
  - Previously, if iterator returned 1 byte in one iteration, we
    would directly send this as a single chunk to the
    API. (GITHUB-408, LIBCLOUD-639) [Peter Schmidt]
  * Loadbalancer
  - Updates to CloudStack driver. (GITHUB-434) [Jeroen de Korte]
  * DNS
  - New driver for Softlayer DNS service. (GITHUB-413, LIBCLOUD-640)
    [Vanč Levstik]
  - Fix a bug with ex_create_multi_value_record method in the
    Route53 driver only returning a single record. (GITHUB-431,
    LIBCLOUD-650) [Itxaka Serrano]
* Mon Nov 24 2014 andrea@opensuse.org
-  New upstream version 0.16.0
  * changes listed on the website:
    https://libcloud.readthedocs.org/en/latest/changelog.html
* Fri Nov 14 2014 andrea@opensuse.org
- Fixed RPM group
* Wed Oct 29 2014 andrea@opensuse.org
- New upstream version 0.15.1
  * changes listed on the website
* Sun Feb  9 2014 aboe76@gmail.com
- Changes with Apache Libcloud 0.14.1
- Compute:
  - Add new m3.medium and m3.large instance information to the EC2 driver. [Tomaz Muraus]
  - Add a new driver for CloudSigma API v2.0. [Tomaz Muraus]
  - Add “volume_id” attribute to the Node “extra” dictionary in the EC2 driver. Also fix the value of the “device” extra attribute in the StorageVolume object. (LIBCLOUD-501) [Oleg Suharev]
  - Add the following extension methods to the OpenStack driver: ex_pause_node, ex_unpause_node, ex_suspend_node, ex_resume_node. (LIBCLOUD-505, GITHUB-238) [Chris DeRamus]
  - Add ex_limits method to the CloudStack driver. (LIBCLOUD-507, GITHUB-240) [Chris DeRamus]
  - Add “extra” dictionary to the CloudStackNode object and include more attributes in the “extra” dictionary of the network and volume object. (LIBCLOUD-506, GITHUB-239) [Chris DeRamus]
  - Add ex_register_image method to the EC2 driver. (LIBCLOUD-508, GITHUB-241) [Chris DeRamus]
  - Add methods for managing volume snapshots to the OpenStack driver. (LIBCLOUD-512, GITHUB-245) [Chris DeRamus]
- Load Balancer:
  - Fix a bug in the ex_targetpool_add_node and ex_targetpool_remove_node method in the GCE driver. [Rick Wright]
- Storage:
  - Allow user to use an internal endpoint in the CloudFiles driver by passing “use_internal_url” argument to the driver constructor. (GITHUB-229, GITHUB-231) [John Obelenus]
- DNS:
  - Add PTR to the supported record types in the Rackspace driver. [Tomaz Muraus]
  - Fix Zerigo driver to set Record.name attribute for records which refer to the bare domain to “None” instead of an empty string. [Tomaz Muraus]
  - For consistency with other drivers, update Rackspace driver to set Record.name attribute for the records which refer to the bare domain to “None” instead of setting them to FQDN. [Tomaz Muraus]
  - Update Rackspace driver to support paginating through zones and records. (GITHUB-230) [Roy Wellington]
  - Update Route53 driver so it supports handling records with multiple values (e.g. MX). (LIBCLOUD-504, GITHUB-237) [Chris DeRamus]
  - Update Route53 driver to better handle SRV records. [Tomaz Muraus]
  - Update Route53 driver, make sure “ttl” attribute in the Record extra dictionary is always an int. [Tomaz Muraus]
* Sat Jan 25 2014 aboe76@gmail.com
- Big release 0.14.0
- General:
  - If the file exists, read pricing data from ~/.libcloud/pricing.json by default.
  If the file doesn’t exist, fall back to the old behavior and use pricing data
    which is bundled with the release. [Tomaz Muraus]
  - Add libcloud.pricing.download_pricing_file function for downloading and
    updating the pricing file. [Tomaz Muraus]
  - Fix libcloud.utils.py3.urlquote so it works with unicode strings
    under Python 2. (LIBCLOUD-429) [Michael Farrell]
- Compute:
  - Refactor Rackspace driver classes and make them easier to use.
    Now there are two Rackspace provider constants - Provider.RACKSPACE which represents
    new next-gen OpenStack servers and Provider.RACKSPACE_FIRST_GEN
    which represents old first-gen cloud servers.
    Note: This change is backward incompatible.
    For more information on those changes and how to update your code,
    please visit “Upgrade Notes” documentation page - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Deprecate the following EC2 provider constants:
    EC2_US_EAST, EC2_EU, EC2_EU_WEST, EC2_AP_SOUTHEAST,
    EC2_AP_NORTHEAST, EC2_US_WEST_OREGON, EC2_SA_EAST,
    EC2_SA_EAST and replace it with a new EC2 constant.
    Driver referenced by this new constant now takes a “region” argument which
    dictates to which region to connect.
    Note: Deprecated constants will continue to work until the next major release.
    For more information on those changes and how to update your code,
    please visit “Upgrade Notes” documentation page - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Add support for volume related functions to OpenNebula driver. (LIBCLOUD-354) [Emanuele Rocca]
  - Add methods for managing storage volumes to the OpenStack driver. (LIBCLOUD-353) [Bernard Kerckenaere]
  - Add new driver for Google Compute Engine (LIBCLOUD-266, LIBCLOUD-386) [Rick Wright]
  - Fix create_node “features” metadata and update affected drivers. (LIBCLOUD-367) [John Carr]
  - Update EC2 driver to accept the auth kwarg (it will accept NodeAuthSSH objects and
    automatically import a public key that is not already uploaded to the EC2 keyring).
    (Follow on from LIBCLOUD-367). [John Carr]
  - Unify extension argument names for assigning a node to security groups in EC2 and OpenStack driver.
    Argument in the EC2 driver has been renamed from ex_securitygroup to ex_security_groups.
    For backward compatibility reasons, old argument will continue to work until the next major release.
    (LIBCLOUD-375) [Tomaz Muraus]
  - Add ex_import_keypair_from_string and ex_import_keypair method to the CloudStack driver.
    (LIBCLOUD-380) [Sebastien Goasguen]
  - Add support for managing floating IP addresses to the OpenStack driver. (LIBCLOUD-382) [Ivan Kusalic]
  - Add extension methods for handling port forwarding to the CloudStack driver,
    rename CloudStackForwardingRule class to CloudStackIPForwardingRule. (LIBCLOUD-348, LIBCLOUD-381) [sebastien goasguen]
  - Hook up deploy_node functionality in the CloudStack driver and unify extension arguments
    for handling security groups. (LIBCLOUD-388) [sebastien goasguen]
  - Allow user to pass “args” argument to the ScriptDeployment and ScriptFileDeployment class.
    This argument tells which command line arguments get passed to the ScriptDeployment script. (LIBCLOUD-394)
    Note: This change is backward incompatible.
    For more information on how this affects your code and how to update it,
    visit “Upgrade Notes” documentation page - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Allow user to specify IAM profile to use when creating an EC2 node. (LIBCLOUD-403) [Xavier Barbosa]
  - Add support for keypair management to the OpenStack driver. (LIBCLOUD-392) [L. Schaub]
  - Allow user to specify disk partitioning mode using ex_disk_config argument in the OpenStack based drivers.
    (LIBCLOUD-402) [Brian Curtin]
  - Add new driver for NephoScale provider (http://nephoscale.com/). (LIBCLOUD-404) [Markos Gogoulos]
  - Update network related extension methods so they work correctly with both, OpenStack and Rackspace driver.
    (LIBCLOUD-368) [Tomaz Muraus]
  - Add tests for networking functionality in the OpenStack and Rackspace driver. [Tomaz Muraus]
  - Allow user to pass all supported extension arguments to ex_rebuild_server method in the OpenStack driver.
    (LIBCLOUD-408) [Dave King]
  - Add pricing information for Rackspace Cloud Sydney region. [Tomaz Muraus]
  - Update EC2 instance type map and pricing data. High Storage instances are now also available in
    Sydney and Singapore region. [Tomaz Muraus]
  - Add new methods for managing storage volumes and snapshots to the EC2 driver (list_volumes,
    list_snapshots, destroy_volume_snapshot, create_volume_snapshot) (LIBCLOUD-409) [Oleg Suharev]
  - Add the following new extension methods to EC2 driver: ex_destroy_image, ex_modify_instance_attributes,
    ex_delete_keypair. (LIBCLOUD-409) [Oleg Suharev]
  - Allow user to specify a port range when creating a port forwarding rule. (LIBCLOUD-409) [Oleg Suharev]
  - Align Joyent driver with other drivers and deprecate “location” argument in the driver constructor
    in favor of “region” argument.
    Note: Deprecated argument will continue to work until the next major release. [Tomaz Muraus]
  - Deprecate the following ElasticHosts provider constants:
    ELASTICHOSTS_UK1, ELASTICHOSTS_UK2, ELASTICHOSTS_US1, ELASTICHOSTS_US2, ELASTICHOSTS_US3,
    ELASTICHOSTS_CA1, ELASTICHOSTS_AU1, ELASTICHOSTS_CN1 and replace it with a new ELASTICHOSTS constant.
    Driver referenced by this new constant now takes a “region” argument which dictates to which region to connect.
    Note: Deprecated constants will continue to work until the next major release. For more information on those changes and
    how to update your code, please visit “Upgrade Notes”
    documentation page - http://s.apache.org/lc0140un (LIBCLOUD-383) [Michael Bennett, Tomaz Muraus]
  - Add log statements to our ParamikoSSHClient wrapper. This should make debugging deployment issues easier.
    (LIBCLOUD-414) [Tomaz Muraus]
  - Add new “NodeState.STOPPED” node state. Update HostVirual and EC2 driver to also recognize this new state.
    (LIBCLOUD-296) [Jayy Vis]
  - Add new Hong Kong endpoint to Rackspace driver. [Brian Curtin]
  - Fix ex_delete_keypair method in the EC2 driver. (LIBCLOUD-415) [Oleg Suharev]
  - Add the following new extension methods for elastic IP management to the EC2 driver:
    ex_allocate_address, ex_disassociate_address, ex_release_address. (LIBCLOUD-417) [Patrick Armstrong]
  - For consistency and accuracy, rename “ex_associate_addresses” method in the EC2 driver to
    “ex_associate_address_with_node”.
    Note: Old method will continue to work until the next major release. [Tomaz Muraus]
  - Add new driver for CloudFrames (http://www.cloudfounders.com/CloudFrames) provider. (LIBCLOUD-358) [Bernard Kerckenaere]
  - Update default kernel versions which are used when creating a Linode server.
    Old default kernel versions:
    x86 - 2.6.18.8-x86_64-linode1
    x86_64 - 2.6.39.1-linode34
    New default kernel versions:
    x86 - 3.9.3-x86-linode52
    x86_64 - 3.9.3-x86_64-linode33
    (LIBCLOUD-424) [Tomaz Muraus, Jon Chen]
  - Disable cache busting functionality in the OpenStack and Rackspace next-gen driver and enable it
    only for Rackspace first-gen driver. [Tomaz Muraus]
  - Update Google Compute Engine driver to v1beta16. [Rick Wright]
  - Modify auth_url variable in the OpenStack drivers so it works more like users would expect it to.
    Previously path specified in the auth_url was ignored and only protocol, hostname and port were used.
    Now user can provide a full url for the auth_url variable and the path provided in the url is also used.
    [DaeMyung Kang, Tomaz Muraus]
  - Allow user to associate arbitrary key/value pairs with a node by passing “ex_metadata” argument
    (dictionary) to create_node method in the EC2 driver. Those values are associated with a node using
    tags functionality. (LIBCLOUD-395) [Ivan Kusalic]
  - Add “ex_get_metadata” method to EC2 and OpenStack driver. This method reads metadata dictionary
    from the Node object. (LIBCLOUD-395) [Ivan Kusalic]
  - Multiple improvements in the Softlayer driver:
  - Map “INITIATING” node state to NodeState.PENDING
  - If node is launching remap “halted” state to “pending”
  - Add more node sizes
  - Add ex_stop_node and ex_start_node method
  - Update tests response fixtures
    (LIBCLOUD-416) [Markos Gogoulos]
  - Modify list_sizes method in the KT UCloud driver to work, even if the item doesn’t have ‘diskofferingid’
    attribute. (LIBCLOUD-435) [DaeMyung Kang]
  - Add new c3 instance types to the EC2 driver. [Tomaz Muraus]
  - Fix an issue with the ex_list_keypairs and ex_list_security_groups method in the CloudStack driver
    which caused an exception to be thrown if the API returned no keypairs / security groups.
    (LIBCLOUD-438) [Carlos Reategui, Tomaz Muraus]
  - Fix a bug in the OpenStack based drivers with not correctly checking if the auth token has expired
    before re-using it. (LIBCLOUD-428)
    Reported by Michael Farrell. [Tomaz Muraus, Michael Farrell]
- Storage
  - Deprecate CLOUDFILES_US and CLOUDFILES_UK provider constant and replace it with a new CLOUDFILES constant.
    Driver referenced by this new constant takes a “region” keyword argument which can be one
    of ‘ord’, ‘dfw’, ‘iad’, ‘syd’, ‘lon’.
    Note: Deprecated constants will continue to work until the next major release.
    For more information on this change, please visit “Upgrade Notes”
    documentation section - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Allow users to filter objects starting with a prefix by passing ex_prefix argument to the list_
    container_objects method in the S3, Google Storage and CloudFiles driver. (LIBCLOUD-369) [Stefan Friesel]
  - Fix an issue with mutating connectionCls.host attribute in the Azure driver. This bug prevented user
    from having multiple Azure drivers with different keys instantiated at the same time. (LIBCLOUD-399) [Olivier Grisel]
  - Add a new driver for KT UCloud based on the OpenStack Swift driver. (LIBCLOUD-431). [DaeMyung Kang]
- Load Balancer:
  - Deprecate RACKSPACE_US and RACKSPACE_UK provider constant and replace it with a new RACKSPACE constant.
    Driver referenced by this new constant takes a “region” keyword argument which can be one of the
    following: ‘ord’, ‘dfw’, ‘iad’, ‘syd’, ‘lon’.
    Note: Deprecated constants will continue to work until the next major release.
    For more information on this change, please visit “Upgrade Notes”
    documentation section - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Add new driver for Google Compute Engine (LIBCLOUD-386) [Rick Wright]
  - Add new Hong Kong endpoint to Rackspace driver. [Brian Curtin]
- DNS:
  - Deprecate RACKSPACE_US and RACKSPACE_UK provider constant and replace it with a new RACKSPACE constant.
    Driver referenced by this new constant takes a “region” keyword argument which can be one of the
    following: ‘us’, ‘uk’.
    Note: Deprecated constants will continue to work until the next major release.
    For more information on this change, please visit “Upgrade Notes”
    documentation section - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Use string instead of integer for RecordType ENUM value.
    Note: If you directly use an integer instead of RecordType ENUM class you need to update your code to
    use the RecordType ENUM otherwise the code won’t work. For more information on how to do that,
    see “Upgrade Notes” documentation section - http://s.apache.org/lc0140un [Tomaz Muraus]
  - Add “export_zone_to_bind_format” and export_zone_to_bind_zone_file method which allows users to
    export Libcloud Zone to BIND zone format. (LIBCLOUD-398) [Tomaz Muraus]
  - Update issue with inexistent zone / record handling in the get_zone and get_record
    method in the Linode driver. Those issues were related to changes in the Linode API. (LIBCLOUD-425) [Jon Chen]
* Thu Jan  2 2014 aboe76@gmail.com
- Updated to 0.13.3 (bnc#857209)
- Security fix release, for destroying nodes on digitalOcean
  'data_scrub' method is always invoked
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Sep 22 2013 aboe76@gmail.com
- Updated to 0.13.2
- General:
  - Don't sent Content-Length: 0 header with POST and PUT request if "raw"
    mode is used. This fixes a regression which could cause broken behavior
    in some storage driver when uploading a file from disk.
- Compute:
  - Added Ubuntu Linux 12.04 image to ElasticHost driver image list.
  (LIBCLOUD-364)
  - Update ElasticHosts driver to store drive UUID in the node 'extra' field.
  (LIBCLOUD-357)
- Storage:
  - Store last_modified timestamp in the Object extra dictionary in the S3
    driver. (LIBCLOUD-373)
- Load Balancer:
  - Expose CloudStack driver directly through the Provider.CLOUDSTACK
    constant.
- DNS:
  - Modify Zerigo driver to include record TTL in the record 'extra' attribute
    if a record has a TTL set.
  - Modify values in the Record 'extra' dictionary attribute in the Zerigo DNS
    driver to be set to None instead of an empty string ('') if a value for
    the provided key is not set.
* Thu Sep  5 2013 aboe76@gmail.com
- Updated to 0.13.1
- General Changes:
  - Fix a regression introduced in 0.13.0 and make sure to include
    Content-Length 0 with PUT and POST requests.
- Compute Changes:
  - Fix a bug in the ElasticHosts driver and check for right HTTP status
    code when determining drive imaging success.
  - Update Opsource driver to include node public ip address (if available).
- Storage Chagnes:
  - Fix a regression with calling encode_container_name instead of
    encode_object_name on object name in get_object method.
  - Ensure that AWS S3 multipart upload works for small iterators.
* Mon Jul  1 2013 aboe76@gmail.com
- Updated to 0.13.0
- General changes:
  - Add homebrew curl-ca-bundle path to CA_CERTS_PATH.
  - Modify OpenStackAuthConnection and change auth_token_expires attribute to
    be a datetime object instead of a string.
  - Modify OpenStackAuthConnection to support re-using of the existing auth
    token if it's still valid instead of re-authenticating on every
    authenticate() call.
  - Modify base Connection class to not send Content-Length header if body is
    not provided.
  - Add the new error class ProviderError and modify InvalidCredsError to
    inherit from it.
- compute changes:
  - Fix destroy_node method in the experimental libvirt driver.
  - Add ex_start_node method to the Joyent driver.
  - Fix Python 3 compatibility issue in the ScriptFileDeployment class.
  - Add ex_set_metadata_entry and ex_get_metadata method to the VCloud driver.
  - Various improvements and bug-fixes in the VCloud driver.
  - Add ex_set_metadata_entry and ex_get_metadata method to the VCloud driver.
  - Modify list_sizes method in the OpenStack driver to include
    OpenStackNodeSize object which includes 'vcpus' attribute which holds
    a number of virtual CPUs for this size.
  - For consistency rename "ex_describe_keypairs" method in the EC2 driver to
    "ex_describe_keypair".
  - Modify "ex_describe_keypair" method to return key fingerprint in the
    return value.
  - Populate private_ips attribute in the CloudStack drive when returning
    a Node object from the create_node method.
  - Allow user to pass extra arguments via "extra_args" argument which are
    then passed to the "deployVirtualMachine" call in the CloudStack driver
    create_node method.
  - Update Gandi driver to handle new billing model.
  - Fix a bug in the Linode driver and remove extra newline which is added
    when generating a random root password in create_node.
  - Add extension methods for managing keypairs to the CloudStack driver.
  - Add extension methods for managing security groups to the CloudStack
    driver.
  - Add extension methods for starting and stoping the node to the
    CloudStack driver.
  - Fix old _wait_until_running method.
  - Fix a bug in the GoGrid driver get_uuid method.
  - Various bug fixes and improvements in the HostVirtual driver.
  - Fix a bug with deploy_node not respecting 'timeout' kwarg.
  - Modify create_node method in CloudStack driver to return an instance of
    CloudStackNode and add a new "expunging" node state.
  - Update API endpoint hostnames in the ElasticHost driver and use hostnames
    which return a valid SSL certificate.
  - Add a driver for Rackspace's new datacenter in Sydney, Australia.
  - Add ex_list_networks method and missing tests for list_templates to the
    CloudStack driver.
  - Correctly throw InvalidCredsError if user passes invalid credentials to
    the DigitalOcean driver.
- storage changes:
  - Fix an issue with double encoding the container name in the CloudFiles
    driver upload_object method.
    Also properly encode container and object name used in the HTTP request
    in the get_container and get_object method.
- load balancer changes:
  - Add ex_list_current_usage method to the Rackspace driver.
* Tue May  7 2013 aboe76@gmail.com
- Updated to 0.12.4
- Fix a regression in Softlayer driver caused by the xmlrpclib changes.
- Allow user to pass alternate ssh usernames to deploy_node
- Fix a bug in EC2 list_locations method - 'name' attribute didn't contain a
  the right value.
- Add new ScriptFileDeployment deployment class which reads deploy script from
  file.
- Add support for API version 5.1 to the vCloud driver and accept any value
  which is a multiple of four for ex_vm_memory kwarg in create_node method.
- Fix a regression with removed ex_force_service_region constructor kwarg in
  the CloudFiles driver.
* Mon Apr 15 2013 aboe76@gmail.com
- Updated to 0.12.3
- Fix Python 3.x related regressions
- Fix a regression introduced with recent xmlrpiclib changes which broke all
  the Gandi.net drivers
- Improve deploy code to work correctly if the ssh user doesn't have access
  to the /root directory.
- Improve public and private IP address handling in OpenStack 1.1 driver.
- Add new driver for DigitalOcean provider
- Fix a regression in ParamikoSSHClient
- Allow user to specify 'priority' extra argument when creating a MX or SRV
  record.
* Tue Feb 19 2013 aboe76@gmail.com
- updated to 0.12.1
- Changes with Apache Libcloud 0.12.1:
  - Deprecate LazyList method of iteration over large paginated collections
    and use a new, more efficient generator based approach which doesn't
    require the iterator to be pre-exhausted and buffering all of the values
    in memory.
    Existing list_* methods which previously used LazyList class are
    preserving the old behavior and new iterate_* methods which use a new
    generator based approach have been added. (LIBCLOUD-254)
    [Mahendra M]
  - Replace old ENUM style provider constants and replace them with a string
    version.
    This change allows users to dynamically register new drivers using a new
    set_driver method. (LIBCLOUD-255)
    [Mahendra M]
  - Allow user to explicitly specify which CA file is used for verifying
    the server certificate by setting 'SSL_CERT_FILE' environment variable.
    Note: When this variable is specified, the specified path is the only
    CA file which is used to verifying the server certificate. (LIBCLOUD-283)
    [Tomaz Muraus, Erinn Looney-Triggs]
  - Add a common module (libcloud.common.xmlrpc) for handling XML-RPC
    requests using Libcloud http layer.
    Also refactor existing drivers which use xmlrpclib directly (VCL, Gandi,
    Softlayer) to use this module.
    This change allows drivers to support LIBCLOUD_DEBUG and SSL certificate
    validation functionality. Previously they have bypassed Libcloud http
    layer so this functionality was not available. (LIBCLOUD-288)
    [John Carr]
  - Fix string interpolation bug in __repr__ methods in the IBM SCE driver.
    (LIBCLOUD-242)
    [Tomaz Muraus]
  - Fix test failures which happened in Python 3.3 due to:
  - hash randomization
  - changes in xml.etree module
  - changes in xmlrpc module
    (LIBCLOUD-245)
    [Tomaz Muraus]
  - Improvements and additions in vCloud driver:
  - Expose generic query method (ex_query)
  - Provide functionality to get and set control access for vApps. This way
    created vApps can be shared between users/groups or everyone.
    (LIBCLOUD-251)
    [Michal Galet]
  - Update EC2 pricing data to reflect new, lower prices -
    http://aws.typepad.com/aws/2012/10/new-ec2-second-generation-standard-instances-and-price-reductions-1.html
    [Tomaz Muraus]
  - Update EC2 instance size to reflect new m3 instance types. Also refactor
    the code to make it easier to maintain.
    [Tomaz Muraus]
  - Add a new driver for HostVirtual (http://www.vr.org) provider.
    (LIBCLOUD-249)
    [Dinesh Bhoopathy]
  - Fix a bug where a numeric instead of a string value was used for the
    content-length header in VCloud driver. (LIBCLOUD-256)
    [Brian DeGeeter, Tomaz Muraus]
  - Add a new driver for new Asia Pacific (Sydney) EC2 region.
    [Tomaz Muraus]
  - Add support for managing security groups to the OpenStack driver. This
    patch adds the following extension methods:
  - ex_list_security_groups, ex_get_node_security_groups methods
  - ex_create_security_group, ex_delete_security_group
  - ex_create_security_group_rule, ex_delete_security_group_rule
    (LIBCLOUD-253)
    [L. Schaub]
  - Modify ElasticStack driver class to pass 'vnc auto' instead of
    'vnc:ip auto' argument to the API when creating a server.
    It looks like 'vnc:ip' has been replaced with 'vnc'.
    [Rick Copeland, Tomaz Muraus]
  - Add new EC2 instance type - High Storage Eight Extra Large Instance
    (hs1.8xlarge).
    [Tomaz Muraus]
  - Map 'shutting-down' node state in EC2 driver to UNKNOWN. Previously
    it was mapped to TERMINATED. (LIBCLOUD-280)
    Note: This change is backward incompatible which means you need to update
    your code if you rely on the old behavior.
    [Tomaz Muraus, Marcin Kuzminski]
  - Change _wait_until_running method so it supports waiting on multiple nodes
    and make it public (wait_until_running). (LIBCLOUD-274)
    [Nick Bailey]
  - Add new EC2 instance type - High Memory Cluster Eight Extra Large.
    (cr1.8xlarge).
    [Tomaz Muraus]
  - Add new driver for Abiquo provider - http://www.abiquo.com (LIBCLOUD-250).
    [Jaume Devesa]
  - Allow user to pass 'ex_blockdevicemappings' kwarg to the EC2 driver
    'create_node' method. (LIBCLOUD-282)
    [Joe Miller, Tomaz Muraus]
  - Improve error handling in the Brightbox driver.
    [Tomaz Muraus]
  - Fix the ScriptDeployment step to work correctly if user provides a
    relative path for the script argument. (LIBCLOUD-278)
    [Jaume Devesa]
  - Fix Softlayer driver and make sure all the code is up to date and works
    with the latest version of the actual Softlayer deployment (v3).
    (LIBCLOUD-287)
    [Kevin McDonald]
  - Update EC2 driver, m3 instance types are now available in all the regions
    except Brazil.
    Also update pricing to reflect new (decreased) prices.
    [Tomaz Muraus]
  - Minor improvements in the HostVirtual driver and add new ex_get_node and
    ex_build_node extension method. (LIBCLOUD-249)
    [Dinesh Bhoopathy]
  - Add ex_destroy_image method to IBM SCE driver. (LIBCLOUD-291)
    [Perry Zou]
  - Add the following new regions to the ElasticHosts driver: sjc-c, syd-v,
    hkg-e. (LIBCLOUD-293)
    [Tomaz Muraus]
  - Fix create_node in OpenStack driver to work correctly if 'adminPass'
    attribute is not present in the response.
    [Gavin McCance, Tomaz Muraus]
  - Allow users to filter images returned by the list_images method in the EC2
    driver by providing ex_image_ids argument. (LIBCLOUD-294)
    [Chris Psaltis, Joseph Hall]
  - Add support for OpenNebula 3.8. (LIBCLOUD-295)
    [Guillaume ZITTA]
  - Add a new local storage driver.
    (LIBCLOUD-252, LIBCLOUD-258, LIBCLOUD-265, LIBCLOUD-273)
    [Mahendra M]
  - Fix a bug which caused the connection to not be closed when using Python
    2.6 and calling get_object on an object which doesn't exist in the S3
    driver. (LIBCLOUD-257)
    [John Carr]
  - Add a new generator based method for listing / iterating over the
    containers (iterate_containers). (LIBCLOUD-261)
    [Mahendra M]
  - Add ex_purge_object_from_cdn method to the CloudFiles driver.
    (LIBCLOUD-267)
    [Tomaz Muraus]
  - Support for multipart uploads and other improvements in the S3 driver
    so it can more easily be re-used with other implementations (e.g. Google
    Storage, etc.).
    Also default to a multipart upload when using upload_object_via_stream.
    This methods is more efficient compared to old approach because it only
    requires buffering a single multipart chunk (5 MB) in memory.
    (LIBCLOUD-269)
    [Mahendra M]
  - Add new driver for Windows Azure Storage with support for block and page
    blobs. (LIBCLOUD-80)
    [Mahendra M]
  - Update 'if type' checks in the update_record methods to behave correctly
    if users passes in RecordType.A with a value of 0 - if type is not None.
    (LIBCLOUD-247)
    [Tomaz Muraus]
  - New driver for HostVirtual provider (www.vr.org). (LIBCLOUD-249)
    [Dinesh Bhoopathy]
  - Finish Amazon Route53 driver. (LIBCLOUD-132)
    [John Carr]
  - Add new driver for Gandi provider (https://www.gandi.net). (LIBCLOUD-281)
    [John Carr]
  - Add new driver for AWS Elastic Load Balancing service. (LIBCLOUD-169)
    [John Carr]
* Wed Jan 30 2013 aboe76@gmail.com
- Updated spec file copyright to Suse
* Mon Jan 28 2013 toddrme2178@gmail.com
- Cleanup spec file
- Fix rpmlint errors
- Rename package to match spec file
* Tue Jan 22 2013 aboe76@gmail.com
- initial upload version 0.11.4
